<?php

namespace Drupal\session_management\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Login setting configuration form.
 */
class LoginSettingsForm extends ConfigFormBase {

  public const SETTINGS = 'session_management.settings';

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames() {
    return [static::SETTINGS];
  }

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'login-settings-form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $form['libraries'] = [
      '#attached' => [
        'library' => [
          "session_management/session_management.mo_session",
        ],
      ],
    ];

    $form['#disabled'] = TRUE;
    $form['div_start'] = [
      '#type' => 'markup',
      '#markup' => '<div class="mo-table-layout-2"><div class="mo-table-layout-3 mo-container1">',
    ];

    $form['login_settings'] = [
      '#type' => 'details',
      '#title' => $this->t('Flood Control [<i>Coming Soon</i>]'),
    ];

    $form['login_settings']['enable_flood_control'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Flood Control'),
    ];

    $form['login_settings']['flood_control_limit'] = [
      '#type' => 'number',
      '#title' => $this->t('Invalid attempts'),
      '#description' => $this->t('The number of invalid login attempts before blocking account.'),
    ];

    $form['login_settings']['error_message_override'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Override default error message'),
      '#description' => $this->t("Disable Drupal core's login error messages, obfuscating the reason for the login failure. This could make it harder for an attacker to discover whether the account even exists."),
      '#rows' => 2,
    ];

    $form['div_end'] = [
      '#type' => 'markup',
      '#markup' => '</div></div>',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
  }

}
